@@ -6,7 +6,6 @@
 
 // Own
 #include "MainWindow.h"
-#include "AppColorSchemeChooser.h"
 
 // Qt
 #include <QMenu>
@@ -19,30 +18,26 @@
 #include <KAcceleratorManager>
 #include <KActionCollection>
 #include <KActionMenu>
+#include <KColorSchemeManager>
+#include <KColorSchemeMenu>
 #include <KCrash>
 #include <KHamburgerMenu>
 #include <KIconUtils>
 #include <KLocalizedString>
-#include <KShortcutsDialog>
-#include <KToolBar>
-#include <KWindowEffects>
-
-#include <kwindowsystem_version.h>
-#if HAVE_X11
-#if KWINDOWSYSTEM_VERSION >= QT_VERSION_CHECK(5, 101, 0)
-#include <KX11Extras>
-#endif
-#endif
-
 #include <KMessageBox>
 #include <KNotifyConfigWidget>
+#include <KShortcutsDialog>
 #include <KStandardAction>
 #include <KStandardGuiItem>
+#include <KToolBar>
+#include <KWindowConfig>
+#include <KWindowEffects>
 #include <KWindowSystem>
 #include <KXMLGUIFactory>
 
-#include <kio_version.h>
-#include <kwidgetsaddons_version.h>
+#if HAVE_X11
+#include <KX11Extras>
+#endif
 
 // Konsole
 #include "BookmarkHandler.h"
@@ -59,6 +54,7 @@
 
 #include "settings/ConfigurationDialog.h"
 #include "settings/GeneralSettings.h"
+#include "settings/MemorySettings.h"
 #include "settings/ProfileSettings.h"
 #include "settings/TabBarSettings.h"
 #include "settings/TemporaryFilesSettings.h"
@@ -132,61 +128,6 @@ MainWindow::MainWindow()
     KCrash::initialize();
 }
 
-// Convenience function to get a space-separated list of all connected screens, copied from KWindowConfig
-static QString allConnectedScreens()
-{
-    QStringList names;
-    const auto screens = QGuiApplication::screens();
-    names.reserve(screens.length());
-    for (auto screen : screens) {
-#ifdef Q_OS_WIN
-        // QScreen::name() returns garbage on Windows; see https://bugreports.qt.io/browse/QTBUG-74317
-        // So we use the screens' serial numbers to identify them instead
-        names << screen->serialNumber();
-#else
-        names << screen->name();
-#endif
-    }
-    return names.join(QLatin1Char(' '));
-}
-
-// Convenience function to get an appropriate config file key under which to
-// save window size, position, or maximization information.
-// Copied from KWindowConfig before https://invent.kde.org/frameworks/kconfig/-/merge_requests/184
-// changed the key format. TODO: use the public function in KWindowConfig for
-// this once it exists.
-static QString configFileStringV1(const QScreen *screen, const QString &key)
-{
-    // We include resolution data to also save data on a per-resolution basis
-    const QString returnString =
-        QStringLiteral("%1 %2 %3x%4 %5")
-            .arg(allConnectedScreens(), key, QString::number(screen->geometry().width()), QString::number(screen->geometry().height()), screen->name());
-    return returnString;
-}
-
-// Convenience function to get an appropriate config file key under which to
-// save window size, position, or maximization information.
-// Copied from KWindowConfig as of https://invent.kde.org/frameworks/kconfig/-/merge_requests/184
-// TODO: use the public function in KWindowConfig for this once it exists.
-static QString configFileStringV2(const QScreen *screen, const QString &key)
-{
-    Q_UNUSED(screen)
-    QString returnString;
-    const int numberOfScreens = QGuiApplication::screens().length();
-
-    if (numberOfScreens == 1) {
-        // For single-screen setups, we save data on a per-resolution basis.
-        const QRect screenGeometry = QGuiApplication::primaryScreen()->geometry();
-        returnString = QStringLiteral("%1x%2 screen: %3").arg(QString::number(screenGeometry.width()), QString::number(screenGeometry.height()), key);
-    } else {
-        // For multi-screen setups, we save data based on the number of screens.
-        // Distinguishing individual screens based on their names is unreliable
-        // due to name strings being inherently volatile.
-        returnString = QStringLiteral("%1 screens: %2").arg(QString::number(numberOfScreens), key);
-    }
-    return returnString;
-}
-
 bool MainWindow::wasWindowGeometrySaved() const
 {
     KSharedConfigPtr konsoleConfig = KSharedConfig::openConfig(QStringLiteral("konsolerc"));
@@ -195,10 +136,7 @@ bool MainWindow::wasWindowGeometrySaved() const
         return false;
     }
 
-    return cg.hasKey(configFileStringV2(screen(), QStringLiteral("Width"))) || cg.hasKey(configFileStringV2(screen(), QStringLiteral("Height")))
-        || cg.hasKey(configFileStringV2(screen(), QStringLiteral("XPosition"))) || cg.hasKey(configFileStringV2(screen(), QStringLiteral("YPosition")))
-        || cg.hasKey(configFileStringV1(screen(), QStringLiteral("Width"))) || cg.hasKey(configFileStringV1(screen(), QStringLiteral("Height")))
-        || cg.hasKey(configFileStringV1(screen(), QStringLiteral("XPosition"))) || cg.hasKey(configFileStringV1(screen(), QStringLiteral("YPosition")));
+    return KWindowConfig::hasSavedWindowSize(cg) || KWindowConfig::hasSavedWindowPosition(cg);
 }
 
 void MainWindow::updateUseTransparency()
@@ -218,7 +156,6 @@ void MainWindow::activationRequest(const QString &xdgActivationToken)
 {
     KWindowSystem::setCurrentXdgActivationToken(xdgActivationToken);
 
-#if KWINDOWSYSTEM_VERSION >= QT_VERSION_CHECK(5, 101, 0)
     if (KWindowSystem::isPlatformX11()) {
 #if HAVE_X11
         KX11Extras::forceActiveWindow(winId());
@@ -226,9 +163,6 @@ void MainWindow::activationRequest(const QString &xdgActivationToken)
     } else {
         KWindowSystem::activateWindow(windowHandle());
     }
-#else
-    KWindowSystem::forceActiveWindow(winId());
-#endif
 }
 
 void MainWindow::rememberMenuAccelerators()
@@ -433,7 +367,14 @@ void MainWindow::setupActions()
     });
 
     // Set up themes
-    actionCollection()->addAction(QStringLiteral("window-colorscheme-menu"), new AppColorSchemeChooser(actionCollection()));
+    auto *manager = new KColorSchemeManager(actionCollection());
+    manager->setAutosaveChanges(true);
+    KActionMenu *selectionMenu = KColorSchemeMenu::createMenu(manager, this);
+    auto winColorSchemeMenu = new QAction(this);
+    winColorSchemeMenu->setMenu(selectionMenu->menu());
+    winColorSchemeMenu->menu()->setIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-color")));
+    winColorSchemeMenu->menu()->setTitle(i18n("&Window Color Scheme"));
+    actionCollection()->addAction(QStringLiteral("window-colorscheme-menu"), winColorSchemeMenu);
 
     // Full Screen
     menuAction = KStandardAction::fullScreen(this, &MainWindow::viewFullScreen, this, collection);
@@ -504,7 +445,7 @@ void MainWindow::updateHamburgerMenu()
 
     menu->addSeparator();
 
-    menu->addAction(collection->action(QLatin1String(KStandardAction::name(KStandardAction::FullScreen))));
+    menu->addAction(collection->action(KStandardAction::name(KStandardAction::FullScreen)));
     menu->addAction(collection->action(QStringLiteral("split-view")));
     menu->addAction(controllerCollection->action(QStringLiteral("clear-history-and-reset")));
     menu->addAction(controllerCollection->action(QStringLiteral("enlarge-font")));
@@ -518,7 +459,8 @@ void MainWindow::updateHamburgerMenu()
 
     menu->addSeparator();
 
-    auto monitorMenu = menu->addMenu(QIcon::fromTheme(QStringLiteral("visibility")), static_cast<QMenu *>(factory()->container(QStringLiteral("view"), nullptr))->title());
+    auto monitorMenu =
+        menu->addMenu(QIcon::fromTheme(QStringLiteral("visibility")), static_cast<QMenu *>(factory()->container(QStringLiteral("view"), nullptr))->title());
     monitorMenu->addAction(controllerCollection->action(QStringLiteral("monitor-silence")));
     monitorMenu->addAction(controllerCollection->action(QStringLiteral("monitor-activity")));
     monitorMenu->addAction(controllerCollection->action(QStringLiteral("monitor-process-finish")));
@@ -533,14 +475,15 @@ void MainWindow::updateHamburgerMenu()
     pluginsMenu->setIcon(QIcon::fromTheme(QStringLiteral("plugins"))); // Icon will be removed again when the menu bar is enabled.
     menu->addMenu(pluginsMenu);
 
-    auto configureMenu = menu->addMenu(QIcon::fromTheme(QStringLiteral("configure")), static_cast<QMenu *>(factory()->container(QStringLiteral("settings"), nullptr))->title());
+    auto configureMenu =
+        menu->addMenu(QIcon::fromTheme(QStringLiteral("configure")), static_cast<QMenu *>(factory()->container(QStringLiteral("settings"), nullptr))->title());
     configureMenu->addAction(toolBarMenuAction());
     configureMenu->addSeparator();
-    configureMenu->addAction(collection->action(QLatin1String(KStandardAction::name(KStandardAction::SwitchApplicationLanguage))));
-    configureMenu->addAction(collection->action(QLatin1String(KStandardAction::name(KStandardAction::KeyBindings))));
-    configureMenu->addAction(collection->action(QLatin1String(KStandardAction::name(KStandardAction::ConfigureToolbars))));
-    configureMenu->addAction(collection->action(QLatin1String(KStandardAction::name(KStandardAction::ConfigureNotifications))));
-    configureMenu->addAction(collection->action(QLatin1String(KStandardAction::name(KStandardAction::Preferences))));
+    configureMenu->addAction(collection->action(KStandardAction::name(KStandardAction::SwitchApplicationLanguage)));
+    configureMenu->addAction(collection->action(KStandardAction::name(KStandardAction::KeyBindings)));
+    configureMenu->addAction(collection->action(KStandardAction::name(KStandardAction::ConfigureToolbars)));
+    configureMenu->addAction(collection->action(KStandardAction::name(KStandardAction::ConfigureNotifications)));
+    configureMenu->addAction(collection->action(KStandardAction::name(KStandardAction::Preferences)));
     _hamburgerMenu->hideActionsOf(configureMenu);
 
     _hamburgerMenu->hideActionsOf(toolBar());
@@ -673,8 +616,7 @@ Session *MainWindow::createSession(Profile::Ptr profile, const QString &director
     auto newView = _viewManager->createView(session);
     _viewManager->activeContainer()->addView(newView);
 
-    _viewManager->activeViewController()->actionCollection()->addActions(
-        {_hamburgerMenu});
+    _viewManager->activeViewController()->actionCollection()->addActions({_hamburgerMenu});
 
     return session;
 }
@@ -765,21 +707,13 @@ bool MainWindow::queryClose()
 
 #if HAVE_X11
     // make sure the window is shown on current desktop and is not minimized
-#if KWINDOWSYSTEM_VERSION >= QT_VERSION_CHECK(5, 101, 0)
     KX11Extras::setOnDesktop(winId(), KX11Extras::currentDesktop());
-#else
-    KWindowSystem::setOnDesktop(winId(), KWindowSystem::currentDesktop());
-#endif
 #endif
     int result;
 
     if (!processesRunning.isEmpty()) {
         if (openTabs == 1) {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             result = KMessageBox::warningTwoActionsList(this,
-#else
-            result = KMessageBox::warningYesNoList(this,
-#endif
                                                         i18ncp("@info",
                                                                "There is a process running in this window. "
                                                                "Do you still want to quit?",
@@ -793,18 +727,10 @@ bool MainWindow::queryClose()
                                                         // don't ask again name is wrong but I can't update.
                                                         // this is not about tabs anymore. it's about empty tabs *or* splits.
                                                         QStringLiteral("CloseAllTabs"));
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             if (result == KMessageBox::SecondaryAction) // SecondaryAction is equal to cancel closing
-#else
-            if (result == KMessageBox::No) // No is equal to cancel closing
-#endif
                 result = KMessageBox::Cancel;
         } else {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             result = KMessageBox::warningTwoActionsCancelList(this,
-#else
-            result = KMessageBox::warningYesNoCancelList(this,
-#endif
                                                               i18ncp("@info",
                                                                      "There is a process running in this window. "
                                                                      "Do you still want to quit?",
@@ -821,11 +747,7 @@ bool MainWindow::queryClose()
                                                               QStringLiteral("CloseAllTabs"));
         }
     } else {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         result = KMessageBox::warningTwoActionsCancel(this,
-#else
-        result = KMessageBox::warningYesNoCancel(this,
-#endif
                                                       i18nc("@info",
                                                             "There are %1 open terminals in this window. "
                                                             "Do you still want to quit?",
@@ -840,17 +762,9 @@ bool MainWindow::queryClose()
     }
 
     switch (result) {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     case KMessageBox::PrimaryAction:
-#else
-    case KMessageBox::Yes:
-#endif
         return true;
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     case KMessageBox::SecondaryAction:
-#else
-    case KMessageBox::No:
-#endif
         if ((!_pluggedController.isNull()) && (!_pluggedController->session().isNull())) {
             if (!(_pluggedController->session()->closeInNormalWay())) {
                 if (_pluggedController->confirmForceClose()) {
@@ -970,6 +884,12 @@ void MainWindow::showSettingsDialog(const bool showProfilePage)
     confDialog->addPage(profilePage, true);
     connect(confDialog, &QDialog::accepted, profileSettings, &ProfileSettings::slotAccepted);
 
+#if defined(Q_OS_LINUX)
+    const QString memoryPageName = i18nc("@title Preferences page name", "Memory");
+    auto memoryPage = new KPageWidgetItem(new MemorySettings(confDialog), memoryPageName);
+    confDialog->addPage(memoryPage, true);
+#endif
+
     const QString tabBarPageName = i18nc("@title Preferences page name", "Tab Bar / Splitters");
     auto tabBarPage = new KPageWidgetItem(new TabBarSettings(confDialog), tabBarPageName);
     tabBarPage->setIcon(QIcon::fromTheme(QStringLiteral("preferences-tabs")));
@@ -1048,15 +968,11 @@ void MainWindow::setBlur(bool blur)
     _blurEnabled = blur;
 
     if (!_pluggedController->isKonsolePart()) {
-#if KWINDOWSYSTEM_VERSION < QT_VERSION_CHECK(5, 82, 0)
-        KWindowEffects::enableBlurBehind(winId(), blur);
-#else
         if (QWindow *window = windowHandle()) {
             KWindowEffects::enableBlurBehind(window, blur);
         } else {
             qCWarning(KonsoleDebug) << "Blur effect couldn't be enabled.";
         }
-#endif
     }
 }
 
@@ -1081,11 +997,7 @@ void MainWindow::setRemoveWindowTitleBarAndFrame(bool frameless)
             const auto oldGeometry = saveGeometry();
             // This happens for every Konsole window. It depends on
             // the fact that every window is processed in single thread
-#if KWINDOWSYSTEM_VERSION >= QT_VERSION_CHECK(5, 101, 0)
             const auto oldActiveWindow = KX11Extras::activeWindow();
-#else
-            const auto oldActiveWindow = KWindowSystem::activeWindow();
-#endif
 
             setWindowFlags(newFlags);
 
@@ -1093,11 +1005,7 @@ void MainWindow::setRemoveWindowTitleBarAndFrame(bool frameless)
             // with previous geometry
             restoreGeometry(oldGeometry);
             setVisible(true);
-#if KWINDOWSYSTEM_VERSION >= QT_VERSION_CHECK(5, 101, 0)
             KX11Extras::activateWindow(oldActiveWindow);
-#else
-            KWindowSystem::activateWindow(oldActiveWindow);
-#endif
 #endif
         } else {
             // Restoring geometry ourselves doesn't work on Wayland
@@ -1173,3 +1081,5 @@ bool MainWindow::focusNextPrevChild(bool v)
 
     return QMainWindow::focusNextPrevChild(v);
 }
+
+#include "moc_MainWindow.cpp"
