@@ -27,17 +27,22 @@
 // Qt
 #include <QDir>
 #include <QFileInfo>
-#include <QtGlobal>
 #include <QHostInfo>
 #include <QStringList>
 #include <QTextStream>
+#include <QtGlobal>
 
 // KDE
 #include <KConfigGroup>
 #include <KSharedConfig>
 #include <KUser>
 
+#if defined(Q_OS_LINUX) || defined(Q_OS_SOLARIS)
+#include <memory>
+#endif
+
 #if defined(Q_OS_FREEBSD) || defined(Q_OS_OPENBSD) || defined(Q_OS_MACOS)
+#include <QSharedPointer>
 #include <sys/sysctl.h>
 #endif
 
@@ -94,6 +99,13 @@ void ProcessInfo::setError(Error error)
 void ProcessInfo::update()
 {
     readCurrentDir(_pid);
+    readProcessName(_pid);
+}
+
+void ProcessInfo::refreshArguments()
+{
+    clearArguments();
+    readArguments(_pid);
 }
 
 QString ProcessInfo::validCurrentDir() const
@@ -321,12 +333,109 @@ void ProcessInfo::setFileError(QFile::FileError error)
 }
 
 #if defined(Q_OS_LINUX)
+#include <QByteArray>
+#include <QDBusArgument>
+#include <QDBusConnection>
+#include <QDBusConnectionInterface>
+#include <QDBusMessage>
+#include <QDBusMetaType>
+#include <QFile>
+#include <QMap>
+#include <QString>
+#include <QThread>
+#include <QVariant>
+
+#include "KonsoleSettings.h"
+
+typedef QPair<QString, QDBusVariant> VariantPair;
+typedef QList<VariantPair> VariantList;
+typedef QList<QPair<QString, VariantList>> EmptyArray;
+
+Q_DECLARE_METATYPE(VariantPair);
+Q_DECLARE_METATYPE(VariantList);
+Q_DECLARE_METATYPE(EmptyArray);
+
+// EmptyArray is a custom type used for the last argument of org.freedesktop.systemd1.Manager.StartTransientUnit
+
+QDBusArgument &operator<<(QDBusArgument &argument, const VariantPair pair)
+{
+    argument.beginStructure();
+    argument << pair.first;
+    argument << pair.second;
+    argument.endStructure();
+
+    return argument;
+}
+
+const QDBusArgument &operator>>(const QDBusArgument &argument, VariantPair &pair)
+{
+    argument.beginStructure();
+    argument >> pair.first;
+    QVariant value;
+    argument >> value;
+    pair.second = qvariant_cast<QDBusVariant>(value);
+    argument.endStructure();
+
+    return argument;
+}
+
+QDBusArgument &operator<<(QDBusArgument &argument, const QPair<QString, VariantList> pair)
+{
+    argument.beginStructure();
+    argument << pair.first;
+    argument << pair.second;
+    argument.endStructure();
+
+    return argument;
+}
+
+const QDBusArgument &operator>>(const QDBusArgument &argument, QPair<QString, VariantList> &pair)
+{
+    argument.beginStructure();
+    argument >> pair.first;
+    VariantList variantList;
+    argument >> variantList;
+    pair.second = variantList;
+    argument.endStructure();
+
+    return argument;
+}
+
 class LinuxProcessInfo : public UnixProcessInfo
 {
 public:
-    explicit LinuxProcessInfo(int pid)
+    explicit LinuxProcessInfo(int pid, int sessionPid)
         : UnixProcessInfo(pid)
     {
+        if (pid == 0 || _cGroupCreationFailed) {
+            return;
+        }
+
+        if (_createdAppCGroupPath.isEmpty() && !_cGroupCreationFailed) {
+            _cGroupCreationFailed = KonsoleSettings::enableMemoryMonitoring() && !initCGroupHierachy(pid);
+            return;
+        }
+
+        const bool isForegroundProcess = sessionPid != -1;
+
+        if (!isForegroundProcess) {
+            _cGroupCreationFailed = !createCGroup(QStringLiteral("tab(%1).scope").arg(pid), pid);
+        } else {
+            _cGroupCreationFailed = !moveToCGroup(getProcCGroup(sessionPid), pid);
+        }
+    }
+
+    static bool setUnitMemLimit(const int newMemHigh)
+    {
+        QFile memHighFile(_createdAppCGroupPath + QDir::separator() + QStringLiteral("memory.high"));
+
+        if (_cGroupCreationFailed || !memHighFile.open(QIODevice::WriteOnly)) {
+            return false;
+        }
+
+        memHighFile.write(QStringLiteral("%1M").arg(newMemHigh).toLocal8Bit());
+
+        return true;
     }
 
 protected:
@@ -348,6 +457,28 @@ protected:
         return true;
     }
 
+    bool readProcessName(int pid) override
+    {
+        Q_UNUSED(pid);
+
+        if (!_infoFile || _infoFile->error() != 0 || !_infoFile->reset()) {
+            return false;
+        }
+
+        const QString data = QString::fromUtf8(_infoFile->readLine());
+
+        if (data.isEmpty()) {
+            setName(data);
+            return false;
+        }
+
+        const int nameStartIdx = data.indexOf(QLatin1Char('(')) + 1;
+        const int nameLength = data.lastIndexOf(QLatin1Char(')')) - nameStartIdx;
+
+        setName(data.mid(nameStartIdx, nameLength));
+        return true;
+    }
+
 private:
     bool readProcInfo(int pid) override
     {
@@ -410,32 +541,33 @@ private:
         //
         // FIELD FIELD (FIELD WITH SPACES) FIELD FIELD
         //
-        QFile processInfo(QStringLiteral("/proc/%1/stat").arg(pid));
-        if (processInfo.open(QIODevice::ReadOnly)) {
-            QTextStream stream(&processInfo);
+        _infoFile = std::make_unique<QFile>(new QFile());
+        _infoFile->setFileName(QStringLiteral("/proc/%1/stat").arg(pid));
+        if (_infoFile->open(QIODevice::ReadOnly)) {
+            QTextStream stream(_infoFile.get());
             const QString &data = stream.readAll();
 
-            int stack = 0;
             int field = 0;
             int pos = 0;
 
             while (pos < data.length()) {
                 QChar c = data[pos];
 
-                if (c == QLatin1Char('(')) {
-                    stack++;
-                } else if (c == QLatin1Char(')')) {
-                    stack--;
-                } else if (stack == 0 && c == QLatin1Char(' ')) {
+                if (c == QLatin1Char(' ')) {
                     field++;
                 } else {
                     switch (field) {
                     case PARENT_PID_FIELD:
                         parentPidString.append(c);
                         break;
-                    case PROCESS_NAME_FIELD:
-                        processNameString.append(c);
+                    case PROCESS_NAME_FIELD: {
+                        pos++;
+                        const int NAME_MAX_LEN = 16;
+                        const int nameEndIdx = data.lastIndexOf(QStringLiteral(")"), pos + NAME_MAX_LEN);
+                        processNameString = data.mid(pos, nameEndIdx - pos);
+                        pos = nameEndIdx;
                         break;
+                    }
                     case GROUP_PROCESS_FIELD:
                         foregroundPidString.append(c);
                         break;
@@ -445,7 +577,7 @@ private:
                 pos++;
             }
         } else {
-            setFileError(processInfo.error());
+            setFileError(_infoFile->error());
             return false;
         }
 
@@ -471,32 +603,138 @@ private:
         return ok;
     }
 
-    bool readArguments(int pid) override
+    QDBusMessage callSmdDBus(const QString &objectPath, const QString &interfaceName, const QString &methodName, const QList<QVariant> &args)
     {
-        // read command-line arguments file found at /proc/<pid>/cmdline
-        // the expected format is a list of strings delimited by null characters,
-        // and ending in a double null character pair.
+        const QString service(QStringLiteral("org.freedesktop.systemd1"));
+        const QString interface(service + QLatin1Char('.') + interfaceName);
+        auto methodCall = QDBusMessage::createMethodCall(service, objectPath, interface, methodName);
+        methodCall.setArguments(args);
 
-        QFile argumentsFile(QStringLiteral("/proc/%1/cmdline").arg(pid));
-        if (argumentsFile.open(QIODevice::ReadOnly)) {
-            QTextStream stream(&argumentsFile);
-            const QString &data = stream.readAll();
+        return QDBusConnection::sessionBus().call(methodCall);
+    }
 
-            const QStringList &argList = data.split(QLatin1Char('\0'));
+    bool initCGroupHierachy(int pid)
+    {
+        qDBusRegisterMetaType<VariantPair>();
+        qDBusRegisterMetaType<VariantList>();
+        qDBusRegisterMetaType<QPair<QString, VariantList>>();
+        qDBusRegisterMetaType<EmptyArray>();
 
-            for (const QString &entry : argList) {
-                if (!entry.isEmpty()) {
-                    addArgument(entry);
-                }
-            }
-        } else {
-            setFileError(argumentsFile.error());
+        const QString managerObjPath(QStringLiteral("/org/freedesktop/systemd1"));
+        const QString appUnitName(QStringLiteral("transientKonsole.scope"));
+
+        // check if systemd dbus services exist
+        if (!QDBusConnection::sessionBus().interface()->isServiceRegistered(QStringLiteral("org.freedesktop.systemd1"))) {
+            return false;
         }
 
+        // get current application cgroup path
+        const QString oldAppCGroupPath(getProcCGroup(getpid()));
+
+        // create application unit
+        VariantList properties;
+        const QList<uint> mainPid({static_cast<quint32>(getpid())});
+
+        properties.append(VariantPair({QStringLiteral("Delegate"), QDBusVariant(QVariant::fromValue(true))}));
+        properties.append(VariantPair({QStringLiteral("ManagedOOMMemoryPressure"), QDBusVariant(QVariant::fromValue(QStringLiteral("kill")))}));
+        properties.append(VariantPair({QStringLiteral("PIDs"), QDBusVariant(QVariant::fromValue(mainPid))}));
+
+        if (!createSystemdUnit(appUnitName, properties)) {
+            return false;
+        }
+
+        // get created app cgroup path
+        while (getProcCGroup(getpid()) == oldAppCGroupPath) {
+            QThread::msleep(100); // wait for new unit to be created
+        }
+
+        _createdAppCGroupPath = getProcCGroup(getpid());
+
+        // create sub cgroups
+        if (!createCGroup(QStringLiteral("main.scope"), getpid()) || !createCGroup(QStringLiteral("tab(%1).scope").arg(pid), pid)) {
+            return false;
+        }
+
+        // enable all controllers
+        QFile appCGroupContsFile(_createdAppCGroupPath + QStringLiteral("/cgroup.controllers"));
+        QFile appCGroupSTContsFile(_createdAppCGroupPath + QStringLiteral("/cgroup.subtree_control"));
+
+        if (!appCGroupContsFile.open(QIODevice::ReadOnly) || !appCGroupSTContsFile.open(QIODevice::WriteOnly)) {
+            setFileError(static_cast<QFile::FileError>(appCGroupContsFile.error() | appCGroupSTContsFile.error()));
+            return false;
+        }
+
+        const QStringList conts(QString::fromUtf8(appCGroupContsFile.readAll()).split(QLatin1Char(' ')));
+        QString contsToEnable;
+
+        for (auto cont : conts) {
+            contsToEnable += QLatin1Char('+') + cont.simplified();
+            if (!conts.endsWith(cont)) {
+                contsToEnable += QLatin1Char(' ');
+            }
+        }
+
+        appCGroupSTContsFile.write(contsToEnable.toLocal8Bit());
+
+        return setUnitMemLimit(KonsoleSettings::memoryLimitValue());
+    }
+
+    QString getProcCGroup(const int pid)
+    {
+        const QString cGroupFilePath(QStringLiteral("/proc/%1/cgroup").arg(pid));
+        QFile cGroupFile(cGroupFilePath);
+
+        if (!cGroupFile.open(QIODevice::ReadOnly)) {
+            setFileError(cGroupFile.error());
+            return QString();
+        }
+
+        const QString data = QString::fromUtf8(cGroupFile.readAll());
+
+        const QString cGroupPath(data.mid(data.lastIndexOf(QLatin1Char(':')) + 1));
+
+        return QString(QStringLiteral("/sys/fs/cgroup") + cGroupPath).trimmed();
+    }
+
+    bool createSystemdUnit(const QString &name, const VariantList &propList)
+    {
+        const QList<QVariant> args({name, QStringLiteral("fail"), QVariant::fromValue(propList), QVariant::fromValue(EmptyArray())});
+
+        return callSmdDBus(QStringLiteral("/org/freedesktop/systemd1"), QStringLiteral("Manager"), QStringLiteral("StartTransientUnit"), args).type()
+            != QDBusMessage::ErrorMessage;
+    }
+
+    bool createCGroup(const QString &name, int initialPid)
+    {
+        const QString newCGroupPath(_createdAppCGroupPath + QLatin1Char('/') + name);
+
+        QDir::root().mkpath(newCGroupPath);
+
+        return moveToCGroup(newCGroupPath, initialPid);
+    }
+
+    bool moveToCGroup(const QString &cGroupPath, int pid)
+    {
+        QFile cGroupProcs(cGroupPath + QStringLiteral("/cgroup.procs"));
+
+        if (!cGroupProcs.open(QIODevice::WriteOnly)) {
+            setFileError(cGroupProcs.error());
+            return false;
+        }
+
+        cGroupProcs.write(QStringLiteral("%1").arg(pid).toLocal8Bit());
+
         return true;
     }
+
+    static QString _createdAppCGroupPath;
+    static bool _cGroupCreationFailed;
+    std::unique_ptr<QFile> _infoFile;
 };
 
+QString LinuxProcessInfo::_createdAppCGroupPath = QString();
+bool LinuxProcessInfo::_cGroupCreationFailed = false;
+
 #elif defined(Q_OS_FREEBSD)
 class FreeBSDProcessInfo : public UnixProcessInfo
 {
@@ -510,8 +748,8 @@ protected:
     bool readCurrentDir(int pid) override
     {
 #if HAVE_OS_DRAGONFLYBSD
-        char buf[PATH_MAX];
         int managementInfoBase[4];
+        char buf[PATH_MAX];
         size_t len;
 
         managementInfoBase[0] = CTL_KERN;
@@ -551,26 +789,43 @@ protected:
 #endif
     }
 
+    bool readProcessName(int pid) override
+    {
+        int managementInfoBase[4];
+
+        managementInfoBase[0] = CTL_KERN;
+        managementInfoBase[1] = KERN_PROC;
+        managementInfoBase[2] = KERN_PROC_ARGS;
+        managementInfoBase[3] = pid;
+
+        auto kInfoProc = getProcInfoStruct(managementInfoBase, 4);
+
+        if (kInfoProc == nullptr) {
+            return false;
+        }
+
+#if HAVE_OS_DRAGONFLYBSD
+        setName(QString::fromUtf8(kInfoProc->kp_comm));
+#else
+        setName(QString::fromUtf8(kInfoProc->ki_comm));
+#endif
+
+        return true;
+    }
+
 private:
     bool readProcInfo(int pid) override
     {
         int managementInfoBase[4];
-        size_t mibLength;
-        struct kinfo_proc *kInfoProc;
 
         managementInfoBase[0] = CTL_KERN;
         managementInfoBase[1] = KERN_PROC;
-        managementInfoBase[2] = KERN_PROC_PID;
+        managementInfoBase[2] = KERN_PROC_ARGS;
         managementInfoBase[3] = pid;
 
-        if (sysctl(managementInfoBase, 4, NULL, &mibLength, NULL, 0) == -1) {
-            return false;
-        }
+        auto kInfoProc = getProcInfoStruct(managementInfoBase, 4);
 
-        kInfoProc = new struct kinfo_proc[mibLength];
-
-        if (sysctl(managementInfoBase, 4, kInfoProc, &mibLength, NULL, 0) == -1) {
-            delete[] kInfoProc;
+        if (kInfoProc == nullptr) {
             return false;
         }
 
@@ -590,14 +845,13 @@ private:
 
         readUserName();
 
-        delete[] kInfoProc;
         return true;
     }
 
     bool readArguments(int pid) override
     {
-        char args[ARG_MAX];
         int managementInfoBase[4];
+        char args[ARG_MAX];
         size_t len;
 
         managementInfoBase[0] = CTL_KERN;
@@ -652,12 +906,9 @@ protected:
         return true;
     }
 
-private:
-    bool readProcInfo(int pid) override
+    bool readProcessName(int pid) override
     {
         int managementInfoBase[6];
-        size_t mibLength;
-        struct kinfo_proc *kInfoProc;
 
         managementInfoBase[0] = CTL_KERN;
         managementInfoBase[1] = KERN_PROC;
@@ -666,16 +917,32 @@ private:
         managementInfoBase[4] = sizeof(struct kinfo_proc);
         managementInfoBase[5] = 1;
 
-        if (::sysctl(managementInfoBase, 6, NULL, &mibLength, NULL, 0) == -1) {
-            qWarning() << "first sysctl() call failed with code" << errno;
+        auto kInfoProc = getProcInfoStruct(managementInfoBase, 6);
+
+        if (kInfoProc == nullptr) {
             return false;
         }
 
-        kInfoProc = (struct kinfo_proc *)malloc(mibLength);
+        setName(QString::fromUtf8(kInfoProc->p_comm));
 
-        if (::sysctl(managementInfoBase, 6, kInfoProc, &mibLength, NULL, 0) == -1) {
-            qWarning() << "second sysctl() call failed with code" << errno;
-            free(kInfoProc);
+        return true;
+    }
+
+private:
+    bool readProcInfo(int pid) override
+    {
+        int managementInfoBase[6];
+
+        managementInfoBase[0] = CTL_KERN;
+        managementInfoBase[1] = KERN_PROC;
+        managementInfoBase[2] = KERN_PROC_PID;
+        managementInfoBase[3] = pid;
+        managementInfoBase[4] = sizeof(struct kinfo_proc);
+        managementInfoBase[5] = 1;
+
+        auto kInfoProc = getProcInfoStruct(managementInfoBase, 6);
+
+        if (kInfoProc == nullptr) {
             return false;
         }
 
@@ -686,7 +953,6 @@ private:
         setUserId(kInfoProc->p_uid);
         setUserName(QString::fromUtf8(kInfoProc->p_login));
 
-        free(kInfoProc);
         return true;
     }
 
@@ -761,75 +1027,78 @@ protected:
         return false;
     }
 
-private:
-    bool readProcInfo(int pid) override
+    bool readProcessName(int pid) override
     {
         int managementInfoBase[4];
-        size_t mibLength;
-        struct kinfo_proc *kInfoProc;
-        QT_STATBUF statInfo;
 
-        // Find the tty device of 'pid' (Example: /dev/ttys001)
         managementInfoBase[0] = CTL_KERN;
         managementInfoBase[1] = KERN_PROC;
         managementInfoBase[2] = KERN_PROC_PID;
         managementInfoBase[3] = pid;
 
-        if (sysctl(managementInfoBase, 4, nullptr, &mibLength, nullptr, 0) == -1) {
-            return false;
-        } else {
-            kInfoProc = new struct kinfo_proc[mibLength];
-            if (sysctl(managementInfoBase, 4, kInfoProc, &mibLength, nullptr, 0) == -1) {
-                delete[] kInfoProc;
-                return false;
-            } else {
-                const QString deviceNumber = QString::fromUtf8(devname(((&kInfoProc->kp_eproc)->e_tdev), S_IFCHR));
-                const QString fullDeviceName = QStringLiteral("/dev/") + deviceNumber.rightJustified(3, QLatin1Char('0'));
+        auto kInfoProc = getProcInfoStruct(managementInfoBase, 4);
 
-                setParentPid(kInfoProc->kp_eproc.e_ppid);
-                setForegroundPid(kInfoProc->kp_eproc.e_pgid);
-
-                delete[] kInfoProc;
-
-                const QByteArray deviceName = fullDeviceName.toLatin1();
-                const char *ttyName = deviceName.data();
-
-                if (QT_STAT(ttyName, &statInfo) != 0) {
-                    return false;
-                }
-
-                // Find all processes attached to ttyName
-                managementInfoBase[0] = CTL_KERN;
-                managementInfoBase[1] = KERN_PROC;
-                managementInfoBase[2] = KERN_PROC_TTY;
-                managementInfoBase[3] = statInfo.st_rdev;
-
-                mibLength = 0;
-                if (sysctl(managementInfoBase, sizeof(managementInfoBase) / sizeof(int), nullptr, &mibLength, nullptr, 0) == -1) {
-                    return false;
-                }
-
-                kInfoProc = new struct kinfo_proc[mibLength];
-                if (sysctl(managementInfoBase, sizeof(managementInfoBase) / sizeof(int), kInfoProc, &mibLength, nullptr, 0) == -1) {
-                    return false;
-                }
-
-                // The foreground program is the first one
-                setName(QString::fromUtf8(kInfoProc->kp_proc.p_comm));
-
-                delete[] kInfoProc;
-            }
-            setPid(pid);
+        if (kInfoProc != nullptr) {
+            setName(QString::fromUtf8(kInfoProc->kp_proc.p_comm));
+            return true;
         }
 
+        return false;
+    }
+
+private:
+    bool readProcInfo(int pid) override
+    {
+        QT_STATBUF statInfo;
+        int managementInfoBase[4];
+
+        managementInfoBase[0] = CTL_KERN;
+        managementInfoBase[1] = KERN_PROC;
+        managementInfoBase[2] = KERN_PROC_PID;
+        managementInfoBase[3] = pid;
+
+        // Find the tty device of 'pid' (Example: /dev/ttys001)
+        auto kInfoProc = getProcInfoStruct(managementInfoBase, 4);
+
+        if (kInfoProc == nullptr) {
+            return false;
+        }
+
+        const QString deviceNumber = QString::fromUtf8(devname(((&kInfoProc->kp_eproc)->e_tdev), S_IFCHR));
+        const QString fullDeviceName = QStringLiteral("/dev/") + deviceNumber.rightJustified(3, QLatin1Char('0'));
+
+        setParentPid(kInfoProc->kp_eproc.e_ppid);
+        setForegroundPid(kInfoProc->kp_eproc.e_pgid);
+
+        const QByteArray deviceName = fullDeviceName.toLatin1();
+        const char *ttyName = deviceName.data();
+
+        if (QT_STAT(ttyName, &statInfo) != 0) {
+            return false;
+        }
+
+        managementInfoBase[2] = KERN_PROC_TTY;
+        managementInfoBase[3] = statInfo.st_rdev;
+
+        // Find all processes attached to ttyName
+        kInfoProc = getProcInfoStruct(managementInfoBase, 4);
+
+        if (kInfoProc == nullptr) {
+            return false;
+        }
+
+        // The foreground program is the first one
+        setName(QString::fromUtf8(kInfoProc->kp_proc.p_comm));
+
+        setPid(pid);
+
         // Get user id - this will allow using username
         struct proc_bsdshortinfo bsdinfo;
         int ret;
         bool ok = false;
         const int fpid = foregroundPid(&ok);
         if (ok) {
-            ret = proc_pidinfo(fpid, PROC_PIDT_SHORTBSDINFO, 0,
-                               &bsdinfo, sizeof(bsdinfo));
+            ret = proc_pidinfo(fpid, PROC_PIDT_SHORTBSDINFO, 0, &bsdinfo, sizeof(bsdinfo));
             if (ret == sizeof(bsdinfo)) {
                 setUserId(bsdinfo.pbsi_uid);
             }
@@ -855,7 +1124,7 @@ private:
 
         // It is not clear on why this fails for some commands
         if (sysctl(managementInfoBase, 3, nullptr, &size, nullptr, 0) == -1) {
-            qWarning()<<"OS_MACOS: unable to obtain argument size for "<<pid;
+            qWarning() << "OS_MACOS: unable to obtain argument size for " << pid;
             return false;
         }
 
@@ -864,7 +1133,7 @@ private:
         procargs.resize(argmax);
 
         if (sysctl(managementInfoBase, 3, &procargs[0], &size, nullptr, 0) == -1) {
-            qWarning()<<"OS_MACOS: unable to obtain arguments for "<<pid;
+            qWarning() << "OS_MACOS: unable to obtain arguments for " << pid;
             return false;
         } else {
             auto args = QString::fromStdString(procargs);
@@ -949,6 +1218,16 @@ protected:
         }
     }
 
+    bool readProcessName(int /*pid*/) override
+    {
+        if (execNameFile->isOpen()) {
+            const QString data(execNameFile->readAll());
+            setName(execNameFile->readAll().constData());
+            return true;
+        }
+        return false;
+    }
+
 private:
     bool readProcInfo(int pid) override
     {
@@ -968,22 +1247,23 @@ private:
             info.pr_psargs[PRARGSZ - 1] = 0;
             addArgument(info.pr_psargs);
         }
+
+        _execNameFile = std::make_unique(new QFile());
+        _execNameFile->setFileName(QString("/proc/%1/execname").arg(pid));
+        _execNameFile->open(QIODevice::ReadOnly);
+
         return true;
     }
 
-    bool readArguments(int /*pid*/) override
-    {
-        // Handled in readProcInfo()
-        return false;
-    }
+    std::unique_ptr<QFile> _execNameFile;
 };
 #endif
 
-ProcessInfo *ProcessInfo::newInstance(int pid)
+ProcessInfo *ProcessInfo::newInstance(int pid, int sessionPid)
 {
     ProcessInfo *info;
 #if defined(Q_OS_LINUX)
-    info = new LinuxProcessInfo(pid);
+    info = new LinuxProcessInfo(pid, sessionPid);
 #elif defined(Q_OS_SOLARIS)
     info = new SolarisProcessInfo(pid);
 #elif defined(Q_OS_MACOS)
