@@ -35,7 +35,6 @@ Pty::Pty(QObject *aParent)
 Pty::Pty(int masterFd, QObject *aParent)
     : KPtyProcess(masterFd, aParent)
 {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     // Must call parent class child process modifier, as it sets file descriptors ...etc
     auto parentChildProcModifier = KPtyProcess::childProcessModifier();
     setChildProcessModifier([parentChildProcModifier = std::move(parentChildProcModifier)]() {
@@ -55,7 +54,6 @@ Pty::Pty(int masterFd, QObject *aParent)
             sigaction(signal, &action, nullptr);
         }
     });
-#endif
 
     _windowColumns = 0;
     _windowLines = 0;
@@ -109,16 +107,7 @@ void Pty::setWindowSize(int columns, int lines, int width, int height)
     _windowHeight = height;
 
     if (pty()->masterFd() >= 0) {
-#if KPTY_VERSION >= QT_VERSION_CHECK(5, 93, 0)
         pty()->setWinSize(_windowLines, _windowColumns, _windowHeight, _windowWidth);
-#else
-        struct winsize w;
-        w.ws_xpixel = _windowWidth;
-        w.ws_ypixel = _windowHeight;
-        w.ws_col = _windowColumns;
-        w.ws_row = _windowLines;
-        ioctl(pty()->masterFd(), TIOCSWINSZ, &w);
-#endif
     }
 }
 
@@ -329,25 +318,6 @@ int Pty::foregroundProcessGroup() const
     return 0;
 }
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-void Pty::setupChildProcess()
-{
-    KPtyProcess::setupChildProcess();
-
-    // reset all signal handlers
-    // this ensures that terminal applications respond to
-    // signals generated via key sequences such as Ctrl+C
-    // (which sends SIGINT)
-    struct sigaction action;
-    sigemptyset(&action.sa_mask);
-    action.sa_handler = SIG_DFL;
-    action.sa_flags = 0;
-    for (int signal = 1; signal < NSIG; signal++) {
-        sigaction(signal, &action, nullptr);
-    }
-}
-#endif // QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-
 #else // Windows backend
 
 #include "ptyqt/conptyprocess.h"
@@ -487,3 +457,5 @@ int Pty::foregroundProcessGroup() const
 }
 
 #endif
+
+#include "moc_Pty.cpp"
