@@ -9,17 +9,11 @@
 
 #include "config-konsole.h"
 
-#include <kwindowsystem_version.h>
-
 #include <QtGlobal>
 
-#include <KWindowSystem>
-
 #if HAVE_X11
-#if KWINDOWSYSTEM_VERSION >= QT_VERSION_CHECK(5, 101, 0)
 #include <KX11Extras>
 #endif
-#endif
 
 using Konsole::WindowSystemInfo;
 
@@ -27,13 +21,9 @@ bool WindowSystemInfo::HAVE_TRANSPARENCY = false;
 
 bool WindowSystemInfo::compositingActive()
 {
-#if KWINDOWSYSTEM_VERSION >= QT_VERSION_CHECK(5, 101, 0)
 #if HAVE_X11
     return KX11Extras::compositingActive();
 #else
     return true;
 #endif
-#else
-    return KWindowSystem::compositingActive();
-#endif
 }
