@@ -98,7 +98,7 @@ void KeyboardTranslatorManager::findTranslators()
     // add the name of each translator to the list and associated
     // the name with a null pointer to indicate that the translator
     // has not yet been loaded from disk
-    for (const QString &translatorPath : qAsConst(list)) {
+    for (const QString &translatorPath : std::as_const(list)) {
         QString name = QFileInfo(translatorPath).completeBaseName();
 
         if (!_translators.contains(name)) {
