@@ -159,7 +159,12 @@ Profile::Ptr ProfileManager::loadProfile(const QString &shortPath)
 
     if (!parentProfilePath.isEmpty()) {
         Profile::Ptr parentProfile = loadProfile(parentProfilePath);
-        newProfile->setParent(parentProfile);
+        // To avoid crashes make sure to NOT set an invalid parent
+        if (parentProfile == nullptr) {
+            qCDebug(KonsoleProfileDebug) << "Profile " << newProfile->name() << " has an invalid parent " << parentProfilePath;
+        } else {
+            newProfile->setParent(parentProfile);
+        }
     }
 
     if (!result) {
@@ -487,3 +492,9 @@ QKeySequence ProfileManager::shortcut(Profile::Ptr profile) const
 
     return it != _shortcuts.cend() ? it->keySeq : QKeySequence{};
 }
+
+// ProfileTest is sourcing profile/ProfileManager.cpp to access helper methods
+// automoc though does not support/detect that scenario,
+// so only generates the moc file in the autogen include folder for the normal source build, but not for the test
+// TODO: move internal methods into separate sources and bundle that into the test, or statically export methods
+// #include "moc_ProfileManager.cpp"
