@@ -62,7 +62,7 @@ void ProfileReader::readProperties(const KConfig &config, Profile::Ptr profile)
         const QString name(QLatin1String(info.name));
 
         if (group.hasKey(name)) {
-            profile->setProperty(info.property, group.readEntry(name, QVariant(info.defaultValue.type())));
+            profile->setProperty(info.property, group.readEntry(name, QVariant(info.defaultValue.metaType())));
         }
     }
 }
