@@ -68,9 +68,7 @@
 #include <sys/types.h>
 #endif
 
-#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 97, 0)
 #include <KSandbox>
-#endif
 #endif // Q_OS_WIN
 
 using namespace Konsole;
@@ -381,7 +379,6 @@ QString Session::checkProgram(const QString &program)
     }
 
 #ifndef Q_OS_WIN
-#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 97, 0)
     if (KSandbox::isFlatpak()) {
         QProcess proc;
         // run "test -x exec" on the host to see if the shell is executable
@@ -393,7 +390,6 @@ QString Session::checkProgram(const QString &program)
         }
         return {};
     }
-#endif
 #endif // Q_OS_WIN
 
     QFileInfo info(exec);
@@ -439,11 +435,9 @@ QString Session::shellSessionId() const
 static QStringList postProcessArgs(const QStringList &args)
 {
 #ifndef Q_OS_WIN
-#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 97, 0)
     if (!KSandbox::isFlatpak()) {
         return args;
     }
-#endif
     QStringList arguments;
     // last arg is the program
     arguments = args;
@@ -486,7 +480,6 @@ void Session::run()
     auto pw = getpwuid(getuid());
     // pw: Do not pass the returned pointer to free.
     if (pw != nullptr) {
-#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 97, 0)
         if (KSandbox::isFlatpak()) {
             QProcess proc;
             proc.setProgram(QStringLiteral("getent"));
@@ -498,9 +491,6 @@ void Session::run()
         } else {
             programs.insert(1, QString::fromLocal8Bit(pw->pw_shell));
         }
-#else
-        programs.insert(1, QString::fromLocal8Bit(pw->pw_shell));
-#endif
     }
 #endif
 
@@ -546,11 +536,9 @@ void Session::run()
 #endif
 
 #ifndef Q_OS_WIN
-#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 97, 0)
     if (KSandbox::isFlatpak()) {
         _shellProcess->pty()->setCTtyEnabled(false); // not possibly inside sandbox
     }
-#endif
 #endif
 
     // this is not strictly accurate use of the COLORFGBG variable.  This does not
@@ -571,7 +559,6 @@ void Session::run()
     addEnvironmentEntry(QStringLiteral("KONSOLE_DBUS_SESSION=%1").arg(dbusObject));
 
 #ifndef Q_OS_WIN
-#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 97, 0)
     const auto originalEnvironment = _shellProcess->environment();
     _shellProcess->setProgram(exec);
     _shellProcess->setArguments(arguments);
@@ -580,10 +567,6 @@ void Session::run()
     arguments = postProcessArgs(context.arguments);
     _shellProcess->setEnvironment(originalEnvironment);
     const auto result = _shellProcess->start(context.program, arguments, _environment);
-#else
-    int result = _shellProcess->start(exec, arguments, _environment);
-#endif
-
 #else // Q_OS_WIN
     const auto size = _emulation->imageSize();
     const int lines = size.height();
@@ -736,13 +719,13 @@ void Session::silenceTimerDone()
         view = _views.first();
     }
 
-    KNotification *notification = KNotification::event(hasFocus() ? QStringLiteral("Silence") : QStringLiteral("SilenceHidden"),
-                                                       i18n("Silence in '%1' (Session '%2')", _displayTitle, _nameTitle),
-                                                       QPixmap(),
-                                                       view,
-                                                       KNotification::CloseWhenWidgetActivated);
-    notification->setDefaultAction(i18n("Show session"));
-    connect(notification, &KNotification::defaultActivated, this, [view, notification]() {
+    KNotification *notification =
+        new KNotification(hasFocus() ? QStringLiteral("Silence") : QStringLiteral("SilenceHidden"), KNotification::CloseWhenWindowActivated);
+    notification->setWindow(view->windowHandle());
+
+    notification->setText(i18n("Silence in '%1' (Session '%2')", _displayTitle, _nameTitle));
+    auto action = notification->addDefaultAction(i18n("Show session"));
+    connect(action, &KNotificationAction::activated, this, [view, notification]() {
         view->notificationClicked(notification->xdgActivationToken());
     });
     if (view->sessionController()->isMonitorOnce()) {
@@ -768,14 +751,14 @@ void Session::updateFlowControlState(bool suspended)
 {
     if (suspended) {
         if (flowControlEnabled()) {
-            for (TerminalDisplay *display : qAsConst(_views)) {
+            for (TerminalDisplay *display : std::as_const(_views)) {
                 if (display->flowControlWarningEnabled()) {
                     display->outputSuspended(true);
                 }
             }
         }
     } else {
-        for (TerminalDisplay *display : qAsConst(_views)) {
+        for (TerminalDisplay *display : std::as_const(_views)) {
             display->outputSuspended(false);
         }
     }
@@ -823,7 +806,7 @@ void Session::updateTerminalSize()
     const int VIEW_COLUMNS_THRESHOLD = 2;
 
     // select largest number of lines and columns that will fit in all visible views
-    for (TerminalDisplay *view : qAsConst(_views)) {
+    for (TerminalDisplay *view : std::as_const(_views)) {
         if (!view->isHidden() && view->lines() >= VIEW_LINES_THRESHOLD && view->columns() >= VIEW_COLUMNS_THRESHOLD) {
             minLines = (minLines == -1) ? view->lines() : qMin(minLines, view->lines());
             minColumns = (minColumns == -1) ? view->columns() : qMin(minColumns, view->columns());
@@ -1085,7 +1068,12 @@ void Session::done(int exitCode, QProcess::ExitStatus exitStatus)
         }
 
         // FIXME: See comments in Session::silenceTimerDone()
-        KNotification::event(QStringLiteral("Finished"), message, QPixmap(), QApplication::activeWindow(), KNotification::CloseWhenWidgetActivated);
+        KNotification *notification = new KNotification(QStringLiteral("Finished"), KNotification::CloseWhenWindowActivated);
+        if (QApplication::activeWindow()) {
+            notification->setWindow(QApplication::activeWindow()->windowHandle());
+        }
+        notification->setText(message);
+        notification->sendEvent();
     }
 
     if (exitStatus != QProcess::NormalExit) {
@@ -1197,7 +1185,7 @@ bool Session::updateForegroundProcessInfo()
     const int foregroundPid = _shellProcess->foregroundProcessGroup();
     if (foregroundPid != _foregroundPid) {
         delete _foregroundProcessInfo;
-        _foregroundProcessInfo = ProcessInfo::newInstance(foregroundPid);
+        _foregroundProcessInfo = ProcessInfo::newInstance(foregroundPid, processId());
         _foregroundPid = foregroundPid;
     }
 
@@ -1225,6 +1213,7 @@ QString Session::getDynamicTitle()
     // format tab titles using process info
     bool ok = false;
     if (process->name(&ok) == QLatin1String("ssh") && ok) {
+        process->refreshArguments();
         sshProcess = std::make_unique<SSHProcessInfo>(*process);
     }
 
@@ -1613,7 +1602,7 @@ void Session::zmodemReadAndSendBlock()
     _zmodemProc->setReadChannel(QProcess::StandardOutput);
     QByteArray data = _zmodemProc->read(ZMODEM_BUFFER_SIZE);
 
-    while (data.count() != 0) {
+    while (!data.isEmpty()) {
         _shellProcess->sendData(data);
         data = _zmodemProc->read(ZMODEM_BUFFER_SIZE);
     }
@@ -1932,15 +1921,16 @@ void Session::handleActivity()
     }
 
     if (_monitorActivity && !_notifiedActivity) {
-        KNotification *notification = KNotification::event(hasFocus() ? QStringLiteral("Activity") : QStringLiteral("ActivityHidden"),
-                                                           i18n("Activity in '%1' (Session '%2')", _displayTitle, _nameTitle),
-                                                           QPixmap(),
-                                                           view,
-                                                           KNotification::CloseWhenWidgetActivated);
-        notification->setDefaultAction(i18n("Show session"));
-        connect(notification, &KNotification::defaultActivated, this, [view, notification]() {
+        KNotification *notification =
+            new KNotification(hasFocus() ? QStringLiteral("Activity") : QStringLiteral("ActivityHidden"), KNotification::CloseWhenWindowActivated);
+        notification->setWindow(view->windowHandle());
+        notification->setText(i18n("Activity in '%1' (Session '%2')", _displayTitle, _nameTitle));
+        auto action = notification->addDefaultAction(i18n("Show session"));
+        connect(action, &KNotificationAction::activated, this, [view, notification]() {
             view->notificationClicked(notification->xdgActivationToken());
         });
+        notification->sendEvent();
+
         if (view->sessionController()->isMonitorOnce()) {
             view->sessionController()->actionCollection()->action(QStringLiteral("monitor-activity"))->setChecked(false);
         }
@@ -1997,3 +1987,5 @@ QColor Session::color() const
 {
     return _tabColor;
 }
+
+#include "moc_Session.cpp"
