@@ -44,21 +44,12 @@
 
 #include <KIO/CommandLauncherJob>
 
-#include <kio_version.h>
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
 #include <KIO/JobUiDelegateFactory>
-#else
-#include <KIO/JobUiDelegate>
-#endif
 #include <KIO/OpenFileManagerWindowJob>
 #include <KIO/OpenUrlJob>
 
 #include <KFileItemListProperties>
 
-#include <kconfigwidgets_version.h>
-#include <kio_version.h>
-#include <kwidgetsaddons_version.h>
-
 // Konsole
 #include "CopyInputDialog.h"
 #include "Emulation.h"
@@ -356,16 +347,15 @@ void SessionController::snapshot()
     if (_monitorProcessFinish) {
         bool isForegroundProcessActive = session()->isForegroundProcessActive();
         if (!_previousForegroundProcessName.isNull() && !isForegroundProcessActive) {
-            KNotification *notification =
-                KNotification::event(session()->hasFocus() ? QStringLiteral("ProcessFinished") : QStringLiteral("ProcessFinishedHidden"),
-                                     i18n("The process '%1' has finished running in session '%2'", _previousForegroundProcessName, session()->nameTitle()),
-                                     QPixmap(),
-                                     view(),
-                                     KNotification::CloseWhenWidgetActivated);
-            notification->setDefaultAction(i18n("Show session"));
-            connect(notification, &KNotification::defaultActivated, this, [this, notification]() {
+            KNotification *notification = new KNotification(session()->hasFocus() ? QStringLiteral("ProcessFinished") : QStringLiteral("ProcessFinishedHidden"),
+                                                            KNotification::CloseWhenWindowActivated);
+            notification->setWindow(view()->windowHandle());
+            notification->setText(i18n("The process '%1' has finished running in session '%2'", _previousForegroundProcessName, session()->nameTitle()));
+            auto action = notification->addDefaultAction(i18n("Show session"));
+            connect(action, &KNotificationAction::activated, this, [this, notification] {
                 view()->notificationClicked(notification->xdgActivationToken());
             });
+            notification->sendEvent();
             if (_monitorOnce) {
                 actionCollection()->action(QStringLiteral("monitor-process-finish"))->setChecked(false);
             }
@@ -560,22 +550,14 @@ void SessionController::handleWebShortcutAction(QAction *action)
         const QUrl url = filterData.uri();
 
         auto *job = new KIO::OpenUrlJob(url);
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
         job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, QApplication::activeWindow()));
-#else
-        job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, QApplication::activeWindow()));
-#endif
         job->start();
     }
 }
 
 void SessionController::configureWebShortcuts()
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    auto job = new KIO::CommandLauncherJob(QStringLiteral("kcmshell5"), {QStringLiteral("webshortcuts")});
-#else
     auto job = new KIO::CommandLauncherJob(QStringLiteral("kcmshell6"), {QStringLiteral("webshortcuts")});
-#endif
     job->start();
 }
 
@@ -681,12 +663,10 @@ void SessionController::setupCommonActions()
     connect(action, &QAction::triggered, this, &SessionController::copy);
 
     action = collection->addAction(QStringLiteral("split-view-left-right"));
-    action->setIcon(QIcon::fromTheme(QStringLiteral("view-split-left-right")));
     action->setText(i18n("Split View Left-Right"));
     connect(action, &QAction::triggered, this, &SessionController::requestSplitViewLeftRight);
 
     action = collection->addAction(QStringLiteral("split-view-top-bottom"));
-    action->setIcon(QIcon::fromTheme(QStringLiteral("view-split-top-bottom")));
     action->setText(i18n("Split View Top-Bottom"));
     connect(action, &QAction::triggered, this, &SessionController::requestSplitViewTopBotton);
 
@@ -773,11 +753,7 @@ void SessionController::setupCommonActions()
     _switchProfileMenu = new KActionMenu(QIcon::fromTheme(QStringLiteral("exchange-positions")), i18n("Switch Profile"), this);
     collection->addAction(QStringLiteral("switch-profile"), _switchProfileMenu);
     connect(_switchProfileMenu->menu(), &QMenu::aboutToShow, this, &Konsole::SessionController::prepareSwitchProfileMenu);
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
     _switchProfileMenu->setPopupMode(QToolButton::MenuButtonPopup);
-#else
-    _switchProfileMenu->setDelayed(false);
-#endif
 
     // History
     _findAction = KStandardAction::find(this, &SessionController::searchBarEvent, collection);
@@ -804,26 +780,10 @@ void SessionController::setupCommonActions()
     collection->addAction(QStringLiteral("set-encoding"), _codecAction);
     _codecAction->setCurrentCodec(QString::fromUtf8(session()->codec()));
     connect(session(), &Konsole::Session::sessionCodecChanged, this, &Konsole::SessionController::updateCodecAction);
-#if KCONFIGWIDGETS_VERSION < QT_VERSION_CHECK(5, 103, 0)
-    connect(_codecAction,
-#if KCONFIGWIDGETS_VERSION >= QT_VERSION_CHECK(5, 78, 0)
-            QOverload<QTextCodec *>::of(&KCodecAction::codecTriggered),
-            this,
-#else
-            QOverload<QTextCodec *>::of(&KCodecAction::triggered),
-            this,
-#endif
-            &Konsole::SessionController::changeCodec);
-#else
-#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
+
     connect(_codecAction, &KCodecAction::codecNameTriggered, this, [this](const QByteArray &codecName) {
         changeCodec(QTextCodec::codecForName(codecName));
-#else
-    connect(_codecAction, &KCodecAction::codecNameTriggered, this, [this](const QString &codecName) {
-        changeCodec(QTextCodec::codecForName(codecName.toUtf8()));
-#endif
     });
-#endif
 
     connect(_codecAction, &KCodecAction::defaultItemTriggered, this, [this] {
         Profile::Ptr profile = SessionManager::instance()->sessionProfile(session());
@@ -887,11 +847,7 @@ void SessionController::setupExtraActions()
     copyInputActions->addAction(copyInputToAllTabsAction);
     copyInputActions->addAction(copyInputToSelectedTabsAction);
     copyInputActions->addAction(copyInputToNoneAction);
-#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
     connect(copyInputActions, &KSelectAction::actionTriggered, this, &Konsole::SessionController::copyInputActionsTriggered);
-#else
-    connect(copyInputActions, QOverload<QAction *>::of(&KSelectAction::triggered), this, &Konsole::SessionController::copyInputActionsTriggered);
-#endif
 
     action = collection->addAction(QStringLiteral("zmodem-upload"), this, &SessionController::zmodemUpload);
     action->setText(i18n("&ZModem Upload..."));
@@ -950,11 +906,7 @@ void SessionController::setupExtraActions()
     // Send signal
     auto *sendSignalActions = collection->add<KSelectAction>(QStringLiteral("send-signal"));
     sendSignalActions->setText(i18n("Send Signal"));
-#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
     connect(sendSignalActions, &KSelectAction::actionTriggered, this, &Konsole::SessionController::sendSignal);
-#else
-    connect(sendSignalActions, QOverload<QAction *>::of(&KSelectAction::triggered), this, &Konsole::SessionController::sendSignal);
-#endif
 
     action = collection->addAction(QStringLiteral("sigstop-signal"));
     action->setText(i18n("&Suspend Task") + QStringLiteral(" (STOP)"));
@@ -1138,21 +1090,13 @@ bool SessionController::confirmClose() const
                 title);
         }
 
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         int result = KMessageBox::warningTwoActions(view()->window(),
-#else
-        int result = KMessageBox::warningYesNo(view()->window(),
-#endif
                                                     question,
                                                     i18n("Confirm Close"),
                                                     KGuiItem(i18nc("@action:button", "Close Program"), QStringLiteral("application-exit")),
                                                     KStandardGuiItem::cancel(),
                                                     QStringLiteral("CloseSingleTab"));
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         return result == KMessageBox::PrimaryAction;
-#else
-        return result == KMessageBox::Yes;
-#endif
     }
     return true;
 }
@@ -1181,20 +1125,12 @@ bool SessionController::confirmForceClose() const
                 title);
         }
 
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         int result = KMessageBox::warningTwoActions(view()->window(),
-#else
-        int result = KMessageBox::warningYesNo(view()->window(),
-#endif
                                                     question,
                                                     i18n("Confirm Close"),
                                                     KGuiItem(i18nc("@action:button", "Kill Program"), QStringLiteral("application-exit")),
                                                     KStandardGuiItem::cancel());
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         return result == KMessageBox::PrimaryAction;
-#else
-        return result == KMessageBox::Yes;
-#endif
     }
     return true;
 }
@@ -1246,11 +1182,7 @@ void SessionController::openBrowser()
     } else {
         const QUrl currentUrl = url().isLocalFile() ? url() : QUrl::fromLocalFile(QDir::homePath());
         auto *job = new KIO::OpenUrlJob(currentUrl);
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
         job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, QApplication::activeWindow()));
-#else
-        job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, QApplication::activeWindow()));
-#endif
         job->start();
     }
 }
@@ -1861,15 +1793,16 @@ void SessionController::resetFontSize()
 void SessionController::notifyPrompt()
 {
     if (session()->isMonitorPrompt()) {
-        KNotification *notification = KNotification::event(session()->hasFocus() ? QStringLiteral("Prompt") : QStringLiteral("PromptHidden"),
-                                                           i18n("The shell prompt is displayed in session '%1'", session()->nameTitle()),
-                                                           QPixmap(),
-                                                           view(),
-                                                           KNotification::CloseWhenWidgetActivated);
-        notification->setDefaultAction(i18n("Show session"));
-        connect(notification, &KNotification::defaultActivated, this, [this, notification]() {
+        KNotification *notification =
+            new KNotification(session()->hasFocus() ? QStringLiteral("Prompt") : QStringLiteral("PromptHidden"), KNotification::CloseWhenWindowActivated);
+        notification->setWindow(view()->windowHandle());
+
+        notification->setText(i18n("The shell prompt is displayed in session '%1'", session()->nameTitle()));
+        auto action = notification->addDefaultAction(i18n("Show session"));
+        connect(action, &KNotificationAction::activated, this, [this, notification] {
             view()->notificationClicked(notification->xdgActivationToken());
         });
+        notification->sendEvent();
         if (_monitorOnce) {
             actionCollection()->action(QStringLiteral("monitor-prompt"))->setChecked(false);
         }
@@ -2034,13 +1967,7 @@ void SessionController::showDisplayContextMenu(const QPoint &position)
         QScopedPointer<KFileItemActions> ac(new KFileItemActions());
         ac->setItemListProperties(props);
 
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 82, 0)
         ac->insertOpenWithActionsTo(popup->actions().value(4, nullptr), popup, QStringList{qApp->desktopFileName()});
-#elif KIO_VERSION >= QT_VERSION_CHECK(5, 78, 0)
-        ac->insertOpenWithActionsTo(popup->actions().value(4, nullptr), popup, QString());
-#else
-        ac->addOpenWithActionsTo(popup);
-#endif
 
         auto newActions = popup->actions();
         for (auto *elm : old) {
@@ -2078,7 +2005,7 @@ void SessionController::showDisplayContextMenu(const QPoint &position)
 
         _preventClose = true;
 
-        auto hamburger = static_cast<KHamburgerMenu *>(actionCollection()->action(QLatin1String(KStandardAction::name(KStandardAction::HamburgerMenu))));
+        auto hamburger = static_cast<KHamburgerMenu *>(actionCollection()->action(KStandardAction::name(KStandardAction::HamburgerMenu)));
         if (hamburger) {
             hamburger->addToMenu(popup);
         }
@@ -2201,3 +2128,5 @@ void SessionController::setVisible(QString name, bool visible)
     }
     actionCollection()->action(name)->setVisible(visible);
 }
+
+#include "moc_SessionController.cpp"
