@@ -61,6 +61,18 @@ class IncrementalSearchBar;
 class HotSpot;
 class Profile;
 
+/**
+ * This function adjusts a rect by adding a 1px border around it. The idea is to
+ * compensate in case of approximation issues on highdpi displays with fractional
+ * scaling applied.
+ * As Qt6 may not be affected by this issue, the adjustment is not added in that
+ * case. Hopefully the compiler ignores this function in that case.
+ */
+inline QRect highdpi_adjust_rect(const QRect &rect)
+{
+    return rect;
+}
+
 /**
  * A widget which displays output from a terminal emulation and sends input keypresses and mouse activity
  * to the terminal.
@@ -791,6 +803,9 @@ private:
     bool _dimWhenInactive = false;
     int _dimValue;
 
+    bool _borderWhenActive = false;
+    QColor _focusBorderColor;
+
     ScrollState _scrollWheelState;
     IncrementalSearchBar *_searchBar = nullptr;
     TerminalHeaderBar *_headerBar = nullptr;
